@@ -11,7 +11,7 @@ types: dict[str, str] = {
     "AWS::APS::RuleGroupsNamespace": "1898bd2e1a2fc3af",
     "AWS::APS::Scraper": "6d167939ca161a78",
     "AWS::APS::Workspace": "0739c3a13c4ccac6",
-    "AWS::ARCRegionSwitch::Plan": "157873619ca0d0eb",
+    "AWS::ARCRegionSwitch::Plan": "f86e2a208e3b2f69",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus": "806adfa6e5aba057",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration": "a2125021f0082633",
     "AWS::AccessAnalyzer::Analyzer": "f05e81a8f1bcb307",
@@ -51,7 +51,7 @@ types: dict[str, str] = {
     "AWS::Athena::NamedQuery": "8adbac6f36c9aa6b",
     "AWS::Athena::PreparedStatement": "f136b10278378b55",
     "AWS::Athena::WorkGroup": "15b478b9836a0d48",
-    "AWS::AutoScaling::AutoScalingGroup": "1176577a6acfd8f9",
+    "AWS::AutoScaling::AutoScalingGroup": "05a01deca7473008",
     "AWS::AutoScaling::LaunchConfiguration": "d4a1a18430ff4776",
     "AWS::AutoScaling::LifecycleHook": "95c6d4e044efc81a",
     "AWS::AutoScaling::ScalingPolicy": "3a71f2160c19e614",
@@ -82,7 +82,7 @@ types: dict[str, str] = {
     "AWS::CloudFormation::Macro": "8517053591f9eceb",
     "AWS::CloudFormation::ResourceDefaultVersion": "f614137749ff39d3",
     "AWS::CloudFormation::ResourceVersion": "cb8c2d939b790590",
-    "AWS::CloudFormation::Stack": "1941e510fbdc7265",
+    "AWS::CloudFormation::Stack": "089169583d0e826d",
     "AWS::CloudFormation::StackSet": "bf26be80cf86dbfd",
     "AWS::CloudFormation::WaitCondition": "6c5dfc2296cd28df",
     "AWS::CloudFormation::WaitConditionHandle": "edba290fd70976a3",
@@ -139,19 +139,19 @@ types: dict[str, str] = {
     "AWS::DMS::InstanceProfile": "b289107706553b44",
     "AWS::DMS::MigrationProject": "b4b035d4b0f0b861",
     "AWS::DataPipeline::Pipeline": "f54867769cc566cf",
-    "AWS::DataSync::Agent": "733ace3e7eff9e68",
-    "AWS::DataSync::LocationAzureBlob": "02a252d30ebe9091",
-    "AWS::DataSync::LocationEFS": "dc695ceb626bd6aa",
-    "AWS::DataSync::LocationFSxLustre": "94324095d22e84c5",
-    "AWS::DataSync::LocationFSxONTAP": "fb2886550a94a821",
-    "AWS::DataSync::LocationFSxOpenZFS": "424eb40c8a341345",
-    "AWS::DataSync::LocationFSxWindows": "7123c04a1159211f",
-    "AWS::DataSync::LocationHDFS": "9b0576d7bd1858ba",
-    "AWS::DataSync::LocationNFS": "bf12cdbf56d7c3b2",
-    "AWS::DataSync::LocationObjectStorage": "65e47a263206c90e",
-    "AWS::DataSync::LocationS3": "34db2462e6e07c08",
-    "AWS::DataSync::LocationSMB": "a045adab4853018c",
-    "AWS::DataSync::Task": "6a02fb3e9861f0e9",
+    "AWS::DataSync::Agent": "5f41806ea8ec42b9",
+    "AWS::DataSync::LocationAzureBlob": "d8a83e58123bc26d",
+    "AWS::DataSync::LocationEFS": "f74b4ff1503e9407",
+    "AWS::DataSync::LocationFSxLustre": "bf64014c70578e21",
+    "AWS::DataSync::LocationFSxONTAP": "f120a7ad0e329aaf",
+    "AWS::DataSync::LocationFSxOpenZFS": "542f58e4d98fb8cf",
+    "AWS::DataSync::LocationFSxWindows": "4fa3850617966c77",
+    "AWS::DataSync::LocationHDFS": "0639306ca013b8ec",
+    "AWS::DataSync::LocationNFS": "2659197742246dcd",
+    "AWS::DataSync::LocationObjectStorage": "a66b77a26a3e1747",
+    "AWS::DataSync::LocationS3": "0190e1a20831d5e0",
+    "AWS::DataSync::LocationSMB": "84f56a8c81ace8fd",
+    "AWS::DataSync::Task": "d896b335ffc11f10",
     "AWS::DirectoryService::MicrosoftAD": "380ff1d3d6a3a290",
     "AWS::DirectoryService::SimpleAD": "6d1dff201c211792",
     "AWS::DynamoDB::GlobalTable": "1789ed6c17b2b960",
@@ -250,8 +250,8 @@ types: dict[str, str] = {
     "AWS::ECR::RegistryScanningConfiguration": "68012043447b437a",
     "AWS::ECR::ReplicationConfiguration": "dc2a377f75525dd4",
     "AWS::ECR::Repository": "d569f41026af3be8",
-    "AWS::ECR::RepositoryCreationTemplate": "260745c34d057c07",
-    "AWS::ECS::CapacityProvider": "5804cc1956f638f2",
+    "AWS::ECR::RepositoryCreationTemplate": "38e9548ebe8ec1f5",
+    "AWS::ECS::CapacityProvider": "683155ff5bdccc42",
     "AWS::ECS::Cluster": "3990111074eac8be",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
     "AWS::ECS::ExpressGatewayService": "5d3c22b7a1c19b87",
@@ -274,7 +274,7 @@ types: dict[str, str] = {
     "AWS::EMR::InstanceFleetConfig": "7c6308bb9ea61ce8",
     "AWS::EMR::InstanceGroupConfig": "57ea4fa9b7b6f658",
     "AWS::EMR::SecurityConfiguration": "59f2b8145f1762e6",
-    "AWS::EMR::Step": "816de91a3e21c0a7",
+    "AWS::EMR::Step": "87ecffcedd5d780a",
     "AWS::ElastiCache::CacheCluster": "1220b6bbd633ae68",
     "AWS::ElastiCache::GlobalReplicationGroup": "2af3062bf5b2cf7f",
     "AWS::ElastiCache::ParameterGroup": "b0e1dec3cd05f739",
@@ -477,6 +477,9 @@ types: dict[str, str] = {
     "AWS::Redshift::EventSubscription": "53db04ab09eaba8e",
     "AWS::Redshift::Integration": "a386ce60053e2aa9",
     "AWS::Redshift::ScheduledAction": "51bcaaee4f45725e",
+    "AWS::RedshiftServerless::Namespace": "5713f5387741d15b",
+    "AWS::RedshiftServerless::Snapshot": "826c5d08e248c956",
+    "AWS::RedshiftServerless::Workgroup": "20492b7e2170a5a9",
     "AWS::ResourceExplorer2::DefaultViewAssociation": "a7cd7349891d3ea3",
     "AWS::ResourceExplorer2::Index": "b67cbdd9ae9d9f39",
     "AWS::ResourceExplorer2::View": "5e2f158811bfdae6",
@@ -499,7 +502,7 @@ types: dict[str, str] = {
     "AWS::Route53Resolver::ResolverRule": "a5bf3dc0f2b44d80",
     "AWS::Route53Resolver::ResolverRuleAssociation": "3e5cdfc8643c083b",
     "AWS::S3::AccessPoint": "e8b95810dd8d6917",
-    "AWS::S3::Bucket": "1aa877c9b86f9e89",
+    "AWS::S3::Bucket": "bc2a891a463ee5ee",
     "AWS::S3::BucketPolicy": "38ad5b8bd8062535",
     "AWS::S3ObjectLambda::AccessPoint": "2d6b2b82a9508114",
     "AWS::S3ObjectLambda::AccessPointPolicy": "fd6328c6c782223a",
@@ -514,8 +517,8 @@ types: dict[str, str] = {
     "AWS::SSM::Association": "ad263c9023f92e0c",
     "AWS::SSM::Document": "8b3a8b629d6edee1",
     "AWS::SSM::MaintenanceWindow": "54b31dcf040d1e3b",
-    "AWS::SSM::MaintenanceWindowTarget": "ab8754ee279cfae2",
-    "AWS::SSM::MaintenanceWindowTask": "4655ff7a49ab0f29",
+    "AWS::SSM::MaintenanceWindowTarget": "16bcb928c1d2233d",
+    "AWS::SSM::MaintenanceWindowTask": "ce68f32e2ef0a575",
     "AWS::SSM::Parameter": "c247b226112c5ae5",
     "AWS::SSM::PatchBaseline": "43cce065b6753223",
     "AWS::SSM::ResourceDataSync": "f92ce1aa6674b7f2",
