@@ -12,7 +12,7 @@ types: dict[str, str] = {
     "AWS::APS::RuleGroupsNamespace": "1898bd2e1a2fc3af",
     "AWS::APS::Scraper": "6d167939ca161a78",
     "AWS::APS::Workspace": "0739c3a13c4ccac6",
-    "AWS::ARCRegionSwitch::Plan": "157873619ca0d0eb",
+    "AWS::ARCRegionSwitch::Plan": "f86e2a208e3b2f69",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus": "806adfa6e5aba057",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration": "a2125021f0082633",
     "AWS::AccessAnalyzer::Analyzer": "f05e81a8f1bcb307",
@@ -53,7 +53,7 @@ types: dict[str, str] = {
     "AWS::ApiGatewayV2::Authorizer": "69107e1e01673765",
     "AWS::ApiGatewayV2::Deployment": "81174b55f308dad3",
     "AWS::ApiGatewayV2::DomainName": "87535a11b8340a18",
-    "AWS::ApiGatewayV2::Integration": "dde532823abe537b",
+    "AWS::ApiGatewayV2::Integration": "77743451e77a7545",
     "AWS::ApiGatewayV2::IntegrationResponse": "a319db9e828555fa",
     "AWS::ApiGatewayV2::Model": "fcc09a7d8ffbd09c",
     "AWS::ApiGatewayV2::Route": "112b036b7d923f13",
@@ -84,7 +84,7 @@ types: dict[str, str] = {
     "AWS::AppMesh::VirtualService": "b6b6bd277d3b2302",
     "AWS::AppStream::AppBlock": "60a3a9b8f43b3525",
     "AWS::AppStream::AppBlockBuilder": "3087e48685697649",
-    "AWS::AppStream::Application": "4cf7a3e8ef43ac54",
+    "AWS::AppStream::Application": "357f39e2d6b0b31d",
     "AWS::AppStream::ApplicationEntitlementAssociation": "35e176c811a25063",
     "AWS::AppStream::ApplicationFleetAssociation": "93b71c4884fff935",
     "AWS::AppStream::DirectoryConfig": "d5a3c7fb900c1e1b",
@@ -117,7 +117,7 @@ types: dict[str, str] = {
     "AWS::Athena::NamedQuery": "8adbac6f36c9aa6b",
     "AWS::Athena::PreparedStatement": "f136b10278378b55",
     "AWS::Athena::WorkGroup": "15b478b9836a0d48",
-    "AWS::AutoScaling::AutoScalingGroup": "1176577a6acfd8f9",
+    "AWS::AutoScaling::AutoScalingGroup": "05a01deca7473008",
     "AWS::AutoScaling::LaunchConfiguration": "d4a1a18430ff4776",
     "AWS::AutoScaling::LifecycleHook": "95c6d4e044efc81a",
     "AWS::AutoScaling::ScalingPolicy": "3a71f2160c19e614",
@@ -153,14 +153,19 @@ types: dict[str, str] = {
     "AWS::Bedrock::Prompt": "63cb5b7f989bfc36",
     "AWS::Bedrock::PromptVersion": "41e3e79078ba156a",
     "AWS::BedrockAgentCore::Gateway": "247c1db4e4082ec0",
-    "AWS::BedrockAgentCore::GatewayTarget": "02ee3ce87cb57fbd",
+    "AWS::BedrockAgentCore::GatewayTarget": "2214118622bce5a2",
     "AWS::BedrockAgentCore::WorkloadIdentity": "78d4c036021cc12e",
     "AWS::Budgets::Budget": "ebac0f729cbbf76a",
     "AWS::Budgets::BudgetsAction": "e06dd2791075c9d6",
     "AWS::CDK::Metadata": "6c85ec990b9ac854",
-    "AWS::CE::AnomalyMonitor": "009a9bf60aad206b",
+    "AWS::CE::AnomalyMonitor": "3238fa7e318e3af7",
     "AWS::CE::AnomalySubscription": "5c01c255f3f4980b",
     "AWS::CE::CostCategory": "0ca417b146507094",
+    "AWS::Cases::CaseRule": "3c901a066e2031a8",
+    "AWS::Cases::Domain": "819687c312320180",
+    "AWS::Cases::Field": "575dad6f219c55da",
+    "AWS::Cases::Layout": "f48d9c43985a0937",
+    "AWS::Cases::Template": "af733164010ae401",
     "AWS::Cassandra::Keyspace": "0bd2067860b304f2",
     "AWS::Cassandra::Table": "cb4f8b935e3eae9c",
     "AWS::Cassandra::Type": "8aec046f867c1dce",
@@ -236,7 +241,7 @@ types: dict[str, str] = {
     "AWS::CodeDeploy::Application": "eea8100bd279b205",
     "AWS::CodeDeploy::DeploymentConfig": "394f39ae21382747",
     "AWS::CodeDeploy::DeploymentGroup": "36c8d71f30ed60e4",
-    "AWS::CodePipeline::CustomActionType": "ab3f9c5bbc8251df",
+    "AWS::CodePipeline::CustomActionType": "726ad61840645aa5",
     "AWS::CodePipeline::Pipeline": "580b88b2161ff941",
     "AWS::CodePipeline::Webhook": "a6ad2a4dc85ed032",
     "AWS::CodeStar::GitHubRepository": "eaeb2974516b47e3",
@@ -249,6 +254,7 @@ types: dict[str, str] = {
     "AWS::Cognito::IdentityPoolRoleAttachment": "2a5296f4ca5a2ff7",
     "AWS::Cognito::LogDeliveryConfiguration": "2e1fa665bc591a0b",
     "AWS::Cognito::ManagedLoginBranding": "5c891e6d32f0ba8d",
+    "AWS::Cognito::Terms": "f5bf1f3a97d979ba",
     "AWS::Cognito::UserPool": "4294848dd5d358d2",
     "AWS::Cognito::UserPoolClient": "56f070dbecb283f1",
     "AWS::Cognito::UserPoolDomain": "b89172fa4b1cf22a",
@@ -274,13 +280,13 @@ types: dict[str, str] = {
     "AWS::Connect::AgentStatus": "e4d33392ae941342",
     "AWS::Connect::ApprovedOrigin": "9d9f12f666c7d568",
     "AWS::Connect::ContactFlow": "e7ed1215a325612c",
-    "AWS::Connect::ContactFlowModule": "e570c838d25e4a0e",
+    "AWS::Connect::ContactFlowModule": "8fa9fa9b46d0415e",
     "AWS::Connect::DataTable": "18cd7792603e69c5",
     "AWS::Connect::DataTableAttribute": "08713b122feb23e4",
     "AWS::Connect::DataTableRecord": "db6c4d160c0da36f",
     "AWS::Connect::EmailAddress": "807b7160b3385afb",
     "AWS::Connect::EvaluationForm": "f723bee2405abd32",
-    "AWS::Connect::HoursOfOperation": "a135dc27c162fc0e",
+    "AWS::Connect::HoursOfOperation": "0ad5f5246de080b7",
     "AWS::Connect::Instance": "818f2e8da01f29d9",
     "AWS::Connect::InstanceStorageConfig": "036e51d554e029ec",
     "AWS::Connect::IntegrationAssociation": "05d606eba9d7fcad",
@@ -305,7 +311,7 @@ types: dict[str, str] = {
     "AWS::ControlTower::EnabledControl": "ac0e492fde8853d9",
     "AWS::ControlTower::LandingZone": "96c88ada196eeb0e",
     "AWS::CustomerProfiles::CalculatedAttributeDefinition": "81da3130233325a0",
-    "AWS::CustomerProfiles::Domain": "659c111393e9e906",
+    "AWS::CustomerProfiles::Domain": "aa830cf9368f9f97",
     "AWS::CustomerProfiles::EventStream": "3f1d9d2ece69a5a6",
     "AWS::CustomerProfiles::EventTrigger": "433ae33b7ce88aca",
     "AWS::CustomerProfiles::Integration": "cc301ddea32cd660",
@@ -314,7 +320,7 @@ types: dict[str, str] = {
     "AWS::DLM::LifecyclePolicy": "0287ea6dffbb40a2",
     "AWS::DMS::Certificate": "89efe57b4144e9ab",
     "AWS::DMS::DataMigration": "ade967581e1dfc34",
-    "AWS::DMS::DataProvider": "7c7365975be25275",
+    "AWS::DMS::DataProvider": "94c68c86840900fc",
     "AWS::DMS::Endpoint": "945bb565b81d0034",
     "AWS::DMS::EventSubscription": "fdd5de7c61bc5946",
     "AWS::DMS::InstanceProfile": "b289107706553b44",
@@ -393,12 +399,12 @@ types: dict[str, str] = {
     "AWS::EC2::CapacityReservationFleet": "3cec76abc326e6e7",
     "AWS::EC2::CarrierGateway": "ac1f397e6adda506",
     "AWS::EC2::ClientVpnAuthorizationRule": "9dfbd181c3c5a54c",
-    "AWS::EC2::ClientVpnEndpoint": "9927a4c168876daf",
+    "AWS::EC2::ClientVpnEndpoint": "d132f32844d7e05e",
     "AWS::EC2::ClientVpnRoute": "f1d130776f4e1473",
     "AWS::EC2::ClientVpnTargetNetworkAssociation": "d69233d655faf0f6",
     "AWS::EC2::CustomerGateway": "4003177e29b1dfc5",
     "AWS::EC2::DHCPOptions": "7794e3a54eaacb7a",
-    "AWS::EC2::EC2Fleet": "2667c807051620b3",
+    "AWS::EC2::EC2Fleet": "46456be2fbbfb010",
     "AWS::EC2::EIP": "cc42df82cdc81e9c",
     "AWS::EC2::EIPAssociation": "a267820d6250f189",
     "AWS::EC2::EgressOnlyInternetGateway": "922c59e19b698eac",
@@ -450,7 +456,7 @@ types: dict[str, str] = {
     "AWS::EC2::SecurityGroupIngress": "367136b2f03f428c",
     "AWS::EC2::SecurityGroupVpcAssociation": "f48680388ee894fe",
     "AWS::EC2::SnapshotBlockPublicAccess": "f6434397a8c7e382",
-    "AWS::EC2::SpotFleet": "d389b8af6ecb0e0b",
+    "AWS::EC2::SpotFleet": "b3c6b5b2f4a5b7d2",
     "AWS::EC2::Subnet": "a60b8dc0c7f50396",
     "AWS::EC2::SubnetCidrBlock": "473785ce782ba18f",
     "AWS::EC2::SubnetNetworkAclAssociation": "6b4f4042734e67b7",
@@ -487,7 +493,7 @@ types: dict[str, str] = {
     "AWS::EC2::VPCGatewayAttachment": "1dc77043848e8e94",
     "AWS::EC2::VPCPeeringConnection": "e01a466d269170ed",
     "AWS::EC2::VPNConcentrator": "78aca3962b6da301",
-    "AWS::EC2::VPNConnection": "0f47659c40e916e6",
+    "AWS::EC2::VPNConnection": "96656bab170e1c0b",
     "AWS::EC2::VPNConnectionRoute": "00194e67a2d7f53d",
     "AWS::EC2::VPNGateway": "1e2f029e99547e1a",
     "AWS::EC2::VPNGatewayRoutePropagation": "5e03d41fa9dc15b9",
@@ -503,9 +509,9 @@ types: dict[str, str] = {
     "AWS::ECR::RegistryScanningConfiguration": "68012043447b437a",
     "AWS::ECR::ReplicationConfiguration": "dc2a377f75525dd4",
     "AWS::ECR::Repository": "d569f41026af3be8",
-    "AWS::ECR::RepositoryCreationTemplate": "260745c34d057c07",
+    "AWS::ECR::RepositoryCreationTemplate": "38e9548ebe8ec1f5",
     "AWS::ECR::SigningConfiguration": "c502bcdb31b67cc1",
-    "AWS::ECS::CapacityProvider": "5804cc1956f638f2",
+    "AWS::ECS::CapacityProvider": "683155ff5bdccc42",
     "AWS::ECS::Cluster": "3990111074eac8be",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
     "AWS::ECS::ExpressGatewayService": "5d3c22b7a1c19b87",
@@ -528,7 +534,7 @@ types: dict[str, str] = {
     "AWS::EMR::InstanceFleetConfig": "7c6308bb9ea61ce8",
     "AWS::EMR::InstanceGroupConfig": "57ea4fa9b7b6f658",
     "AWS::EMR::SecurityConfiguration": "59f2b8145f1762e6",
-    "AWS::EMR::Step": "816de91a3e21c0a7",
+    "AWS::EMR::Step": "87ecffcedd5d780a",
     "AWS::EMR::Studio": "5562dc4dee066fd3",
     "AWS::EMR::StudioSessionMapping": "68073ac17f83b5d4",
     "AWS::EMR::WALWorkspace": "1acf5569fff4fcbe",
@@ -621,7 +627,7 @@ types: dict[str, str] = {
     "AWS::Glue::SchemaVersionMetadata": "e531f6334f8eeda7",
     "AWS::Glue::SecurityConfiguration": "066142ba850e9899",
     "AWS::Glue::Table": "2528cdc058dacdf8",
-    "AWS::Glue::TableOptimizer": "301880d31f452b08",
+    "AWS::Glue::TableOptimizer": "6b0597c4dd2d5360",
     "AWS::Glue::Trigger": "efdf04c0265f5aff",
     "AWS::Glue::UsageProfile": "c43f6252ac5a4f73",
     "AWS::Glue::Workflow": "7889f86fa2b1958f",
@@ -732,7 +738,7 @@ types: dict[str, str] = {
     "AWS::IoT::ThingGroup": "7fa472878da23f08",
     "AWS::IoT::ThingPrincipalAttachment": "cb2db377e7001773",
     "AWS::IoT::ThingType": "472326c990487efa",
-    "AWS::IoT::TopicRule": "b031e429916b85bb",
+    "AWS::IoT::TopicRule": "4fcf915e11a87a98",
     "AWS::IoT::TopicRuleDestination": "1113af4de44b3cb0",
     "AWS::IoTEvents::AlarmModel": "9663bd41a6ba5243",
     "AWS::IoTEvents::DetectorModel": "0527d423b1402c41",
@@ -817,7 +823,7 @@ types: dict[str, str] = {
     "AWS::Logs::QueryDefinition": "7b82b12db189c1d9",
     "AWS::Logs::ResourcePolicy": "d7898253a7730ac3",
     "AWS::Logs::SubscriptionFilter": "57635d7dc5bd3e61",
-    "AWS::Logs::Transformer": "4d1796b2fa0445b0",
+    "AWS::Logs::Transformer": "66b4b09c596d83c0",
     "AWS::LookoutEquipment::InferenceScheduler": "854115f97396fd8e",
     "AWS::LookoutVision::Project": "89603d4b475081ea",
     "AWS::M2::Application": "7c1b78891b93a215",
@@ -881,7 +887,7 @@ types: dict[str, str] = {
     "AWS::MediaTailor::Channel": "fe2dcc2566975851",
     "AWS::MediaTailor::ChannelPolicy": "1c9cf783f5b18afb",
     "AWS::MediaTailor::LiveSource": "a884632fe226b938",
-    "AWS::MediaTailor::PlaybackConfiguration": "190be0c2c7795486",
+    "AWS::MediaTailor::PlaybackConfiguration": "45549228850e8811",
     "AWS::MediaTailor::SourceLocation": "7ddd02a26d6de0a4",
     "AWS::MediaTailor::VodSource": "746fa4c2fdf8d70a",
     "AWS::MemoryDB::ACL": "92db73d1650765a6",
@@ -987,7 +993,7 @@ types: dict[str, str] = {
     "AWS::QLDB::Stream": "09aa8fbe0fae7277",
     "AWS::QuickSight::Analysis": "9ed141915b114fbd",
     "AWS::QuickSight::CustomPermissions": "ac2895cdbe3ee0f3",
-    "AWS::QuickSight::Dashboard": "c75bfb3b0c668dfa",
+    "AWS::QuickSight::Dashboard": "b1b7368590994f86",
     "AWS::QuickSight::DataSet": "0e9e94a2fd9e8f95",
     "AWS::QuickSight::DataSource": "2c06940063cc0519",
     "AWS::QuickSight::Folder": "4a9e4af92dbcc718",
@@ -1051,7 +1057,7 @@ types: dict[str, str] = {
     "AWS::Route53::KeySigningKey": "a9a67ae6c371fcf4",
     "AWS::Route53::RecordSet": "c01e9eccec2e3b83",
     "AWS::Route53::RecordSetGroup": "8300e7c48d942273",
-    "AWS::Route53Profiles::Profile": "cf36999836466e94",
+    "AWS::Route53Profiles::Profile": "cb0a28f9bebd044e",
     "AWS::Route53Profiles::ProfileAssociation": "fa568e44f7d9e9f2",
     "AWS::Route53Profiles::ProfileResourceAssociation": "73d6b9da50afa75b",
     "AWS::Route53Resolver::FirewallDomainList": "76957613d7f85b1b",
@@ -1127,8 +1133,8 @@ types: dict[str, str] = {
     "AWS::SSM::Association": "ad263c9023f92e0c",
     "AWS::SSM::Document": "8b3a8b629d6edee1",
     "AWS::SSM::MaintenanceWindow": "54b31dcf040d1e3b",
-    "AWS::SSM::MaintenanceWindowTarget": "ab8754ee279cfae2",
-    "AWS::SSM::MaintenanceWindowTask": "4655ff7a49ab0f29",
+    "AWS::SSM::MaintenanceWindowTarget": "16bcb928c1d2233d",
+    "AWS::SSM::MaintenanceWindowTask": "ce68f32e2ef0a575",
     "AWS::SSM::Parameter": "c247b226112c5ae5",
     "AWS::SSM::PatchBaseline": "43cce065b6753223",
     "AWS::SSM::ResourceDataSync": "f92ce1aa6674b7f2",
@@ -1189,7 +1195,7 @@ types: dict[str, str] = {
     "AWS::SecurityHub::AutomationRule": "f6c9ad12353e867b",
     "AWS::SecurityHub::AutomationRuleV2": "382b90fb3949f096",
     "AWS::SecurityHub::ConfigurationPolicy": "acb80ff79b887cb5",
-    "AWS::SecurityHub::ConnectorV2": "11285780497e0a3f",
+    "AWS::SecurityHub::ConnectorV2": "b4e780d54c354d65",
     "AWS::SecurityHub::DelegatedAdmin": "a328fc62a9f2f7e2",
     "AWS::SecurityHub::FindingAggregator": "7a4c95623ee48fcd",
     "AWS::SecurityHub::Hub": "9f6cb2d8967bfcf6",
