@@ -11,7 +11,7 @@ types: dict[str, str] = {
     "AWS::APS::RuleGroupsNamespace": "1898bd2e1a2fc3af",
     "AWS::APS::Scraper": "6d167939ca161a78",
     "AWS::APS::Workspace": "0739c3a13c4ccac6",
-    "AWS::ARCRegionSwitch::Plan": "157873619ca0d0eb",
+    "AWS::ARCRegionSwitch::Plan": "f86e2a208e3b2f69",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus": "806adfa6e5aba057",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration": "a2125021f0082633",
     "AWS::AccessAnalyzer::Analyzer": "f05e81a8f1bcb307",
@@ -52,7 +52,7 @@ types: dict[str, str] = {
     "AWS::ApiGatewayV2::Authorizer": "69107e1e01673765",
     "AWS::ApiGatewayV2::Deployment": "81174b55f308dad3",
     "AWS::ApiGatewayV2::DomainName": "87535a11b8340a18",
-    "AWS::ApiGatewayV2::Integration": "dde532823abe537b",
+    "AWS::ApiGatewayV2::Integration": "77743451e77a7545",
     "AWS::ApiGatewayV2::IntegrationResponse": "a319db9e828555fa",
     "AWS::ApiGatewayV2::Model": "fcc09a7d8ffbd09c",
     "AWS::ApiGatewayV2::Route": "112b036b7d923f13",
@@ -98,7 +98,7 @@ types: dict[str, str] = {
     "AWS::Athena::NamedQuery": "8adbac6f36c9aa6b",
     "AWS::Athena::PreparedStatement": "f136b10278378b55",
     "AWS::Athena::WorkGroup": "98125aa523006e5f",
-    "AWS::AutoScaling::AutoScalingGroup": "8fe2b009cdacf409",
+    "AWS::AutoScaling::AutoScalingGroup": "05a01deca7473008",
     "AWS::AutoScaling::LaunchConfiguration": "d4a1a18430ff4776",
     "AWS::AutoScaling::LifecycleHook": "95c6d4e044efc81a",
     "AWS::AutoScaling::ScalingPolicy": "3a71f2160c19e614",
@@ -198,7 +198,7 @@ types: dict[str, str] = {
     "AWS::CodeDeploy::Application": "eea8100bd279b205",
     "AWS::CodeDeploy::DeploymentConfig": "394f39ae21382747",
     "AWS::CodeDeploy::DeploymentGroup": "36c8d71f30ed60e4",
-    "AWS::CodePipeline::CustomActionType": "ab3f9c5bbc8251df",
+    "AWS::CodePipeline::CustomActionType": "726ad61840645aa5",
     "AWS::CodePipeline::Pipeline": "580b88b2161ff941",
     "AWS::CodePipeline::Webhook": "a6ad2a4dc85ed032",
     "AWS::Cognito::IdentityPool": "3df22057c8e2ef54",
@@ -206,6 +206,7 @@ types: dict[str, str] = {
     "AWS::Cognito::IdentityPoolRoleAttachment": "2a5296f4ca5a2ff7",
     "AWS::Cognito::LogDeliveryConfiguration": "2e1fa665bc591a0b",
     "AWS::Cognito::ManagedLoginBranding": "5c891e6d32f0ba8d",
+    "AWS::Cognito::Terms": "f5bf1f3a97d979ba",
     "AWS::Cognito::UserPool": "4294848dd5d358d2",
     "AWS::Cognito::UserPoolClient": "56f070dbecb283f1",
     "AWS::Cognito::UserPoolDomain": "b89172fa4b1cf22a",
@@ -234,7 +235,7 @@ types: dict[str, str] = {
     "AWS::Connect::DataTableAttribute": "08713b122feb23e4",
     "AWS::Connect::DataTableRecord": "db6c4d160c0da36f",
     "AWS::Connect::EmailAddress": "807b7160b3385afb",
-    "AWS::Connect::HoursOfOperation": "a135dc27c162fc0e",
+    "AWS::Connect::HoursOfOperation": "0ad5f5246de080b7",
     "AWS::Connect::Instance": "818f2e8da01f29d9",
     "AWS::Connect::InstanceStorageConfig": "036e51d554e029ec",
     "AWS::Connect::IntegrationAssociation": "05d606eba9d7fcad",
@@ -247,7 +248,7 @@ types: dict[str, str] = {
     "AWS::Connect::SecurityKey": "e9f93d5d01b7cd8a",
     "AWS::Connect::SecurityProfile": "c9c4f736d5dba585",
     "AWS::Connect::TrafficDistributionGroup": "f1ac9f1d5792c0ec",
-    "AWS::Connect::User": "5a64b3c240666284",
+    "AWS::Connect::User": "a8153643f0e82b34",
     "AWS::Connect::UserHierarchyGroup": "7cf5994e34fb0eee",
     "AWS::Connect::UserHierarchyStructure": "69430fd905006f57",
     "AWS::ControlTower::EnabledBaseline": "fc45dfb83aa6dd82",
@@ -389,10 +390,10 @@ types: dict[str, str] = {
     "AWS::ECR::ReplicationConfiguration": "dc2a377f75525dd4",
     "AWS::ECR::Repository": "d569f41026af3be8",
     "AWS::ECR::RepositoryCreationTemplate": "38e9548ebe8ec1f5",
-    "AWS::ECS::CapacityProvider": "5804cc1956f638f2",
+    "AWS::ECS::CapacityProvider": "683155ff5bdccc42",
     "AWS::ECS::Cluster": "3990111074eac8be",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
-    "AWS::ECS::ExpressGatewayService": "5d3c22b7a1c19b87",
+    "AWS::ECS::ExpressGatewayService": "a04769bd1a468834",
     "AWS::ECS::PrimaryTaskSet": "d8ea9e906cb85b80",
     "AWS::ECS::Service": "585001d48158728c",
     "AWS::ECS::TaskDefinition": "ac3c5ff140cb5d7d",
@@ -412,7 +413,7 @@ types: dict[str, str] = {
     "AWS::EMR::InstanceFleetConfig": "7c6308bb9ea61ce8",
     "AWS::EMR::InstanceGroupConfig": "57ea4fa9b7b6f658",
     "AWS::EMR::SecurityConfiguration": "59f2b8145f1762e6",
-    "AWS::EMR::Step": "816de91a3e21c0a7",
+    "AWS::EMR::Step": "87ecffcedd5d780a",
     "AWS::EMR::Studio": "5562dc4dee066fd3",
     "AWS::EMR::StudioSessionMapping": "68073ac17f83b5d4",
     "AWS::EMR::WALWorkspace": "1acf5569fff4fcbe",
@@ -622,7 +623,7 @@ types: dict[str, str] = {
     "AWS::MediaTailor::Channel": "fe2dcc2566975851",
     "AWS::MediaTailor::ChannelPolicy": "1c9cf783f5b18afb",
     "AWS::MediaTailor::LiveSource": "a884632fe226b938",
-    "AWS::MediaTailor::PlaybackConfiguration": "190be0c2c7795486",
+    "AWS::MediaTailor::PlaybackConfiguration": "45549228850e8811",
     "AWS::MediaTailor::SourceLocation": "7ddd02a26d6de0a4",
     "AWS::MediaTailor::VodSource": "746fa4c2fdf8d70a",
     "AWS::Neptune::DBCluster": "8d9215c18d4689e5",
@@ -631,6 +632,8 @@ types: dict[str, str] = {
     "AWS::Neptune::DBParameterGroup": "6b2f9cd1b2702ccf",
     "AWS::Neptune::DBSubnetGroup": "c59d053f84ba853c",
     "AWS::Neptune::EventSubscription": "291cb01f3cbffb3e",
+    "AWS::NeptuneGraph::Graph": "4a3e36b32b0fc6ff",
+    "AWS::NeptuneGraph::PrivateGraphEndpoint": "1bcd2ff6cb6de3cf",
     "AWS::NetworkFirewall::Firewall": "e72dd64edb0563ec",
     "AWS::NetworkFirewall::FirewallPolicy": "23d185da5cfdceca",
     "AWS::NetworkFirewall::LoggingConfiguration": "24065655a3066a83",
@@ -688,7 +691,7 @@ types: dict[str, str] = {
     "AWS::PCAConnectorSCEP::Challenge": "66f2129c2055583e",
     "AWS::PCAConnectorSCEP::Connector": "9cbd2b6a05e6eb0d",
     "AWS::PaymentCryptography::Alias": "04360ee15415de2d",
-    "AWS::PaymentCryptography::Key": "af3314970ea9b730",
+    "AWS::PaymentCryptography::Key": "af26a71fe21eb480",
     "AWS::Pipes::Pipe": "052457cd8332df71",
     "AWS::RAM::Permission": "740a6e8ada63a5a3",
     "AWS::RAM::ResourceShare": "b4b5ff31bc5f95b0",
@@ -742,7 +745,7 @@ types: dict[str, str] = {
     "AWS::Route53::KeySigningKey": "a9a67ae6c371fcf4",
     "AWS::Route53::RecordSet": "c01e9eccec2e3b83",
     "AWS::Route53::RecordSetGroup": "8300e7c48d942273",
-    "AWS::Route53Profiles::Profile": "cf36999836466e94",
+    "AWS::Route53Profiles::Profile": "cb0a28f9bebd044e",
     "AWS::Route53Profiles::ProfileAssociation": "fa568e44f7d9e9f2",
     "AWS::Route53Profiles::ProfileResourceAssociation": "73d6b9da50afa75b",
     "AWS::Route53Resolver::FirewallDomainList": "76957613d7f85b1b",
@@ -760,7 +763,7 @@ types: dict[str, str] = {
     "AWS::S3::AccessGrantsInstance": "05d3e874b43bbad8",
     "AWS::S3::AccessGrantsLocation": "3a7be1727f630029",
     "AWS::S3::AccessPoint": "e8b95810dd8d6917",
-    "AWS::S3::Bucket": "bc2a891a463ee5ee",
+    "AWS::S3::Bucket": "f2e96ae4922bbb57",
     "AWS::S3::BucketPolicy": "38ad5b8bd8062535",
     "AWS::S3::MultiRegionAccessPoint": "193323be1bf2dac0",
     "AWS::S3::MultiRegionAccessPointPolicy": "7ac84076052ddd16",
@@ -864,7 +867,7 @@ types: dict[str, str] = {
     "AWS::SecurityHub::AutomationRule": "f6c9ad12353e867b",
     "AWS::SecurityHub::AutomationRuleV2": "382b90fb3949f096",
     "AWS::SecurityHub::ConfigurationPolicy": "acb80ff79b887cb5",
-    "AWS::SecurityHub::ConnectorV2": "11285780497e0a3f",
+    "AWS::SecurityHub::ConnectorV2": "b4e780d54c354d65",
     "AWS::SecurityHub::DelegatedAdmin": "a328fc62a9f2f7e2",
     "AWS::SecurityHub::FindingAggregator": "7a4c95623ee48fcd",
     "AWS::SecurityHub::Hub": "9f6cb2d8967bfcf6",
