@@ -12,7 +12,7 @@ types: dict[str, str] = {
     "AWS::APS::RuleGroupsNamespace": "1898bd2e1a2fc3af",
     "AWS::APS::Scraper": "6d167939ca161a78",
     "AWS::APS::Workspace": "0739c3a13c4ccac6",
-    "AWS::ARCRegionSwitch::Plan": "157873619ca0d0eb",
+    "AWS::ARCRegionSwitch::Plan": "f86e2a208e3b2f69",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus": "806adfa6e5aba057",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration": "a2125021f0082633",
     "AWS::AccessAnalyzer::Analyzer": "f05e81a8f1bcb307",
@@ -47,7 +47,7 @@ types: dict[str, str] = {
     "AWS::ApiGatewayV2::Authorizer": "69107e1e01673765",
     "AWS::ApiGatewayV2::Deployment": "81174b55f308dad3",
     "AWS::ApiGatewayV2::DomainName": "87535a11b8340a18",
-    "AWS::ApiGatewayV2::Integration": "dde532823abe537b",
+    "AWS::ApiGatewayV2::Integration": "77743451e77a7545",
     "AWS::ApiGatewayV2::IntegrationResponse": "a319db9e828555fa",
     "AWS::ApiGatewayV2::Model": "fcc09a7d8ffbd09c",
     "AWS::ApiGatewayV2::Route": "112b036b7d923f13",
@@ -65,7 +65,7 @@ types: dict[str, str] = {
     "AWS::AppConfig::HostedConfigurationVersion": "4d2f292068fae1c6",
     "AWS::AppStream::AppBlock": "60a3a9b8f43b3525",
     "AWS::AppStream::AppBlockBuilder": "3087e48685697649",
-    "AWS::AppStream::Application": "4cf7a3e8ef43ac54",
+    "AWS::AppStream::Application": "357f39e2d6b0b31d",
     "AWS::AppStream::ApplicationEntitlementAssociation": "35e176c811a25063",
     "AWS::AppStream::ApplicationFleetAssociation": "93b71c4884fff935",
     "AWS::AppStream::DirectoryConfig": "d5a3c7fb900c1e1b",
@@ -97,7 +97,7 @@ types: dict[str, str] = {
     "AWS::Athena::NamedQuery": "8adbac6f36c9aa6b",
     "AWS::Athena::PreparedStatement": "f136b10278378b55",
     "AWS::Athena::WorkGroup": "98125aa523006e5f",
-    "AWS::AutoScaling::AutoScalingGroup": "1176577a6acfd8f9",
+    "AWS::AutoScaling::AutoScalingGroup": "05a01deca7473008",
     "AWS::AutoScaling::LaunchConfiguration": "d4a1a18430ff4776",
     "AWS::AutoScaling::LifecycleHook": "95c6d4e044efc81a",
     "AWS::AutoScaling::ScalingPolicy": "3a71f2160c19e614",
@@ -128,7 +128,7 @@ types: dict[str, str] = {
     "AWS::CloudFormation::Macro": "8517053591f9eceb",
     "AWS::CloudFormation::ResourceDefaultVersion": "f614137749ff39d3",
     "AWS::CloudFormation::ResourceVersion": "cb8c2d939b790590",
-    "AWS::CloudFormation::Stack": "1941e510fbdc7265",
+    "AWS::CloudFormation::Stack": "089169583d0e826d",
     "AWS::CloudFormation::StackSet": "bf26be80cf86dbfd",
     "AWS::CloudFormation::WaitCondition": "6c5dfc2296cd28df",
     "AWS::CloudFormation::WaitConditionHandle": "edba290fd70976a3",
@@ -171,6 +171,7 @@ types: dict[str, str] = {
     "AWS::Cognito::IdentityPoolRoleAttachment": "2a5296f4ca5a2ff7",
     "AWS::Cognito::LogDeliveryConfiguration": "2e1fa665bc591a0b",
     "AWS::Cognito::ManagedLoginBranding": "5c891e6d32f0ba8d",
+    "AWS::Cognito::Terms": "f5bf1f3a97d979ba",
     "AWS::Cognito::UserPool": "4294848dd5d358d2",
     "AWS::Cognito::UserPoolClient": "56f070dbecb283f1",
     "AWS::Cognito::UserPoolDomain": "b89172fa4b1cf22a",
@@ -199,19 +200,19 @@ types: dict[str, str] = {
     "AWS::DMS::InstanceProfile": "b289107706553b44",
     "AWS::DMS::MigrationProject": "b4b035d4b0f0b861",
     "AWS::DataPipeline::Pipeline": "f54867769cc566cf",
-    "AWS::DataSync::Agent": "733ace3e7eff9e68",
-    "AWS::DataSync::LocationAzureBlob": "02a252d30ebe9091",
-    "AWS::DataSync::LocationEFS": "dc695ceb626bd6aa",
-    "AWS::DataSync::LocationFSxLustre": "94324095d22e84c5",
-    "AWS::DataSync::LocationFSxONTAP": "fb2886550a94a821",
-    "AWS::DataSync::LocationFSxOpenZFS": "424eb40c8a341345",
-    "AWS::DataSync::LocationFSxWindows": "7123c04a1159211f",
-    "AWS::DataSync::LocationHDFS": "9b0576d7bd1858ba",
-    "AWS::DataSync::LocationNFS": "bf12cdbf56d7c3b2",
-    "AWS::DataSync::LocationObjectStorage": "65e47a263206c90e",
-    "AWS::DataSync::LocationS3": "34db2462e6e07c08",
-    "AWS::DataSync::LocationSMB": "a045adab4853018c",
-    "AWS::DataSync::Task": "6a02fb3e9861f0e9",
+    "AWS::DataSync::Agent": "5f41806ea8ec42b9",
+    "AWS::DataSync::LocationAzureBlob": "d8a83e58123bc26d",
+    "AWS::DataSync::LocationEFS": "f74b4ff1503e9407",
+    "AWS::DataSync::LocationFSxLustre": "bf64014c70578e21",
+    "AWS::DataSync::LocationFSxONTAP": "f120a7ad0e329aaf",
+    "AWS::DataSync::LocationFSxOpenZFS": "542f58e4d98fb8cf",
+    "AWS::DataSync::LocationFSxWindows": "4fa3850617966c77",
+    "AWS::DataSync::LocationHDFS": "0639306ca013b8ec",
+    "AWS::DataSync::LocationNFS": "2659197742246dcd",
+    "AWS::DataSync::LocationObjectStorage": "a66b77a26a3e1747",
+    "AWS::DataSync::LocationS3": "0190e1a20831d5e0",
+    "AWS::DataSync::LocationSMB": "84f56a8c81ace8fd",
+    "AWS::DataSync::Task": "d896b335ffc11f10",
     "AWS::DataZone::DataSource": "45679439037c4108",
     "AWS::DataZone::Domain": "a73fade42476d81b",
     "AWS::DataZone::DomainUnit": "711f0c6aabf717bd",
@@ -239,7 +240,7 @@ types: dict[str, str] = {
     "AWS::EC2::ClientVpnTargetNetworkAssociation": "d69233d655faf0f6",
     "AWS::EC2::CustomerGateway": "4003177e29b1dfc5",
     "AWS::EC2::DHCPOptions": "7794e3a54eaacb7a",
-    "AWS::EC2::EC2Fleet": "2667c807051620b3",
+    "AWS::EC2::EC2Fleet": "46456be2fbbfb010",
     "AWS::EC2::EIP": "cc42df82cdc81e9c",
     "AWS::EC2::EIPAssociation": "a267820d6250f189",
     "AWS::EC2::EgressOnlyInternetGateway": "922c59e19b698eac",
@@ -283,7 +284,7 @@ types: dict[str, str] = {
     "AWS::EC2::SecurityGroupIngress": "367136b2f03f428c",
     "AWS::EC2::SecurityGroupVpcAssociation": "f48680388ee894fe",
     "AWS::EC2::SnapshotBlockPublicAccess": "f6434397a8c7e382",
-    "AWS::EC2::SpotFleet": "d389b8af6ecb0e0b",
+    "AWS::EC2::SpotFleet": "b3c6b5b2f4a5b7d2",
     "AWS::EC2::Subnet": "a60b8dc0c7f50396",
     "AWS::EC2::SubnetCidrBlock": "473785ce782ba18f",
     "AWS::EC2::SubnetNetworkAclAssociation": "6b4f4042734e67b7",
@@ -320,7 +321,7 @@ types: dict[str, str] = {
     "AWS::EC2::VPCGatewayAttachment": "1dc77043848e8e94",
     "AWS::EC2::VPCPeeringConnection": "e01a466d269170ed",
     "AWS::EC2::VPNConcentrator": "78aca3962b6da301",
-    "AWS::EC2::VPNConnection": "0f47659c40e916e6",
+    "AWS::EC2::VPNConnection": "96656bab170e1c0b",
     "AWS::EC2::VPNConnectionRoute": "00194e67a2d7f53d",
     "AWS::EC2::VPNGateway": "1e2f029e99547e1a",
     "AWS::EC2::VPNGatewayRoutePropagation": "5e03d41fa9dc15b9",
@@ -332,8 +333,8 @@ types: dict[str, str] = {
     "AWS::ECR::RegistryScanningConfiguration": "68012043447b437a",
     "AWS::ECR::ReplicationConfiguration": "dc2a377f75525dd4",
     "AWS::ECR::Repository": "d569f41026af3be8",
-    "AWS::ECR::RepositoryCreationTemplate": "260745c34d057c07",
-    "AWS::ECS::CapacityProvider": "5804cc1956f638f2",
+    "AWS::ECR::RepositoryCreationTemplate": "38e9548ebe8ec1f5",
+    "AWS::ECS::CapacityProvider": "683155ff5bdccc42",
     "AWS::ECS::Cluster": "3990111074eac8be",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
     "AWS::ECS::ExpressGatewayService": "5d3c22b7a1c19b87",
@@ -356,7 +357,7 @@ types: dict[str, str] = {
     "AWS::EMR::InstanceFleetConfig": "7c6308bb9ea61ce8",
     "AWS::EMR::InstanceGroupConfig": "57ea4fa9b7b6f658",
     "AWS::EMR::SecurityConfiguration": "59f2b8145f1762e6",
-    "AWS::EMR::Step": "816de91a3e21c0a7",
+    "AWS::EMR::Step": "87ecffcedd5d780a",
     "AWS::EVS::Environment": "8cbba6115db38908",
     "AWS::ElastiCache::CacheCluster": "1220b6bbd633ae68",
     "AWS::ElastiCache::GlobalReplicationGroup": "2af3062bf5b2cf7f",
@@ -446,7 +447,7 @@ types: dict[str, str] = {
     "AWS::ImageBuilder::Component": "c686558ba853a496",
     "AWS::ImageBuilder::ContainerRecipe": "882a5a874ec51f81",
     "AWS::ImageBuilder::DistributionConfiguration": "7b34e1b0b9958d96",
-    "AWS::ImageBuilder::Image": "c690c6fdfc55f601",
+    "AWS::ImageBuilder::Image": "7eaad9cf0d30061e",
     "AWS::ImageBuilder::ImagePipeline": "8ea2eca13ceb1fc8",
     "AWS::ImageBuilder::ImageRecipe": "83c0121011689366",
     "AWS::ImageBuilder::InfrastructureConfiguration": "703bdd9fb961cbcd",
@@ -482,7 +483,7 @@ types: dict[str, str] = {
     "AWS::IoT::ThingGroup": "7fa472878da23f08",
     "AWS::IoT::ThingPrincipalAttachment": "cb2db377e7001773",
     "AWS::IoT::ThingType": "472326c990487efa",
-    "AWS::IoT::TopicRule": "b031e429916b85bb",
+    "AWS::IoT::TopicRule": "4fcf915e11a87a98",
     "AWS::IoT::TopicRuleDestination": "1113af4de44b3cb0",
     "AWS::KMS::Alias": "28f10f922a4d194f",
     "AWS::KMS::Key": "c70e396ee12ddb65",
@@ -532,7 +533,7 @@ types: dict[str, str] = {
     "AWS::Logs::QueryDefinition": "7b82b12db189c1d9",
     "AWS::Logs::ResourcePolicy": "d7898253a7730ac3",
     "AWS::Logs::SubscriptionFilter": "57635d7dc5bd3e61",
-    "AWS::Logs::Transformer": "4d1796b2fa0445b0",
+    "AWS::Logs::Transformer": "66b4b09c596d83c0",
     "AWS::MSK::BatchScramSecret": "ff2b807a577495b0",
     "AWS::MSK::Cluster": "07d7025a3ae5e3bb",
     "AWS::MSK::ClusterPolicy": "b60740da22ea8c04",
@@ -540,6 +541,12 @@ types: dict[str, str] = {
     "AWS::MSK::Replicator": "5b655e344006b494",
     "AWS::MSK::VpcConnection": "6aeb07916b90c80a",
     "AWS::MWAA::Environment": "c28ab3624f1d638c",
+    "AWS::MediaTailor::Channel": "fe2dcc2566975851",
+    "AWS::MediaTailor::ChannelPolicy": "1c9cf783f5b18afb",
+    "AWS::MediaTailor::LiveSource": "a884632fe226b938",
+    "AWS::MediaTailor::PlaybackConfiguration": "45549228850e8811",
+    "AWS::MediaTailor::SourceLocation": "7ddd02a26d6de0a4",
+    "AWS::MediaTailor::VodSource": "746fa4c2fdf8d70a",
     "AWS::Neptune::DBCluster": "8d9215c18d4689e5",
     "AWS::Neptune::DBClusterParameterGroup": "d3f072d3d16a7a5f",
     "AWS::Neptune::DBInstance": "40928fad97bbb2cd",
@@ -570,6 +577,10 @@ types: dict[str, str] = {
     "AWS::NetworkManager::VpcAttachment": "2e2ebc8d6a69d76c",
     "AWS::Oam::Link": "4d4e114e0f615d82",
     "AWS::Oam::Sink": "81957ea027e4c201",
+    "AWS::ObservabilityAdmin::OrganizationTelemetryRule": "4f702fc11306cf74",
+    "AWS::ObservabilityAdmin::S3TableIntegration": "9dcd4f79cf41f229",
+    "AWS::ObservabilityAdmin::TelemetryPipelines": "1acc5affc6615ad2",
+    "AWS::ObservabilityAdmin::TelemetryRule": "a54d5e794c37e6c1",
     "AWS::OpenSearchService::Domain": "1c09878d526db02c",
     "AWS::OpsWorks::App": "508d500b32261320",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment": "4902f6030931194b",
@@ -635,7 +646,7 @@ types: dict[str, str] = {
     "AWS::Route53::KeySigningKey": "a9a67ae6c371fcf4",
     "AWS::Route53::RecordSet": "c01e9eccec2e3b83",
     "AWS::Route53::RecordSetGroup": "8300e7c48d942273",
-    "AWS::Route53Profiles::Profile": "cf36999836466e94",
+    "AWS::Route53Profiles::Profile": "cb0a28f9bebd044e",
     "AWS::Route53Profiles::ProfileAssociation": "fa568e44f7d9e9f2",
     "AWS::Route53Profiles::ProfileResourceAssociation": "73d6b9da50afa75b",
     "AWS::Route53Resolver::FirewallDomainList": "76957613d7f85b1b",
@@ -652,7 +663,7 @@ types: dict[str, str] = {
     "AWS::S3::AccessGrantsInstance": "05d3e874b43bbad8",
     "AWS::S3::AccessGrantsLocation": "3a7be1727f630029",
     "AWS::S3::AccessPoint": "e8b95810dd8d6917",
-    "AWS::S3::Bucket": "1aa877c9b86f9e89",
+    "AWS::S3::Bucket": "bc2a891a463ee5ee",
     "AWS::S3::BucketPolicy": "38ad5b8bd8062535",
     "AWS::S3ObjectLambda::AccessPoint": "2d6b2b82a9508114",
     "AWS::S3ObjectLambda::AccessPointPolicy": "fd6328c6c782223a",
@@ -689,8 +700,8 @@ types: dict[str, str] = {
     "AWS::SSM::Association": "ad263c9023f92e0c",
     "AWS::SSM::Document": "8b3a8b629d6edee1",
     "AWS::SSM::MaintenanceWindow": "54b31dcf040d1e3b",
-    "AWS::SSM::MaintenanceWindowTarget": "ab8754ee279cfae2",
-    "AWS::SSM::MaintenanceWindowTask": "4655ff7a49ab0f29",
+    "AWS::SSM::MaintenanceWindowTarget": "16bcb928c1d2233d",
+    "AWS::SSM::MaintenanceWindowTask": "ce68f32e2ef0a575",
     "AWS::SSM::Parameter": "c247b226112c5ae5",
     "AWS::SSM::PatchBaseline": "43cce065b6753223",
     "AWS::SSM::ResourceDataSync": "f92ce1aa6674b7f2",
@@ -714,7 +725,7 @@ types: dict[str, str] = {
     "AWS::SecretsManager::SecretTargetAttachment": "3bf4404734c82308",
     "AWS::SecurityHub::AutomationRule": "f6c9ad12353e867b",
     "AWS::SecurityHub::AutomationRuleV2": "382b90fb3949f096",
-    "AWS::SecurityHub::ConnectorV2": "11285780497e0a3f",
+    "AWS::SecurityHub::ConnectorV2": "b4e780d54c354d65",
     "AWS::SecurityHub::DelegatedAdmin": "a328fc62a9f2f7e2",
     "AWS::SecurityHub::Hub": "9f6cb2d8967bfcf6",
     "AWS::SecurityHub::HubV2": "b1544234a77fc9a5",
