@@ -40,7 +40,7 @@ types: dict[str, str] = {
     "AWS::ApiGatewayV2::Authorizer": "69107e1e01673765",
     "AWS::ApiGatewayV2::Deployment": "81174b55f308dad3",
     "AWS::ApiGatewayV2::DomainName": "87535a11b8340a18",
-    "AWS::ApiGatewayV2::Integration": "dde532823abe537b",
+    "AWS::ApiGatewayV2::Integration": "77743451e77a7545",
     "AWS::ApiGatewayV2::IntegrationResponse": "a319db9e828555fa",
     "AWS::ApiGatewayV2::Model": "fcc09a7d8ffbd09c",
     "AWS::ApiGatewayV2::Route": "112b036b7d923f13",
@@ -87,7 +87,7 @@ types: dict[str, str] = {
     "AWS::Athena::NamedQuery": "8adbac6f36c9aa6b",
     "AWS::Athena::PreparedStatement": "f136b10278378b55",
     "AWS::Athena::WorkGroup": "15b478b9836a0d48",
-    "AWS::AutoScaling::AutoScalingGroup": "1176577a6acfd8f9",
+    "AWS::AutoScaling::AutoScalingGroup": "05a01deca7473008",
     "AWS::AutoScaling::LaunchConfiguration": "d4a1a18430ff4776",
     "AWS::AutoScaling::LifecycleHook": "95c6d4e044efc81a",
     "AWS::AutoScaling::ScalingPolicy": "3a71f2160c19e614",
@@ -152,7 +152,7 @@ types: dict[str, str] = {
     "AWS::CodeDeploy::Application": "eea8100bd279b205",
     "AWS::CodeDeploy::DeploymentConfig": "394f39ae21382747",
     "AWS::CodeDeploy::DeploymentGroup": "36c8d71f30ed60e4",
-    "AWS::CodePipeline::CustomActionType": "ab3f9c5bbc8251df",
+    "AWS::CodePipeline::CustomActionType": "726ad61840645aa5",
     "AWS::CodePipeline::Pipeline": "580b88b2161ff941",
     "AWS::CodePipeline::Webhook": "a6ad2a4dc85ed032",
     "AWS::Config::AggregationAuthorization": "8957a0832482c5e3",
@@ -165,7 +165,7 @@ types: dict[str, str] = {
     "AWS::Config::StoredQuery": "c02d3b47f92dac62",
     "AWS::DAX::Cluster": "73661849b5d2e253",
     "AWS::DAX::ParameterGroup": "e4ed25409be90eb7",
-    "AWS::DAX::SubnetGroup": "567c520398fc6499",
+    "AWS::DAX::SubnetGroup": "dacf469edd64e22d",
     "AWS::DLM::LifecyclePolicy": "0287ea6dffbb40a2",
     "AWS::DMS::Certificate": "89efe57b4144e9ab",
     "AWS::DMS::DataProvider": "7c7365975be25275",
@@ -208,7 +208,7 @@ types: dict[str, str] = {
     "AWS::EC2::CapacityReservationFleet": "3cec76abc326e6e7",
     "AWS::EC2::CustomerGateway": "5c3cdba89933c1e2",
     "AWS::EC2::DHCPOptions": "7794e3a54eaacb7a",
-    "AWS::EC2::EC2Fleet": "2667c807051620b3",
+    "AWS::EC2::EC2Fleet": "46456be2fbbfb010",
     "AWS::EC2::EIP": "cc42df82cdc81e9c",
     "AWS::EC2::EIPAssociation": "a267820d6250f189",
     "AWS::EC2::EgressOnlyInternetGateway": "922c59e19b698eac",
@@ -243,7 +243,7 @@ types: dict[str, str] = {
     "AWS::EC2::SecurityGroupIngress": "367136b2f03f428c",
     "AWS::EC2::SecurityGroupVpcAssociation": "f48680388ee894fe",
     "AWS::EC2::SnapshotBlockPublicAccess": "f6434397a8c7e382",
-    "AWS::EC2::SpotFleet": "d389b8af6ecb0e0b",
+    "AWS::EC2::SpotFleet": "b3c6b5b2f4a5b7d2",
     "AWS::EC2::Subnet": "a60b8dc0c7f50396",
     "AWS::EC2::SubnetCidrBlock": "1a908a4f15831681",
     "AWS::EC2::SubnetNetworkAclAssociation": "6b4f4042734e67b7",
@@ -290,12 +290,12 @@ types: dict[str, str] = {
     "AWS::ECR::RegistryScanningConfiguration": "68012043447b437a",
     "AWS::ECR::ReplicationConfiguration": "dc2a377f75525dd4",
     "AWS::ECR::Repository": "d569f41026af3be8",
-    "AWS::ECR::RepositoryCreationTemplate": "260745c34d057c07",
-    "AWS::ECS::CapacityProvider": "5804cc1956f638f2",
+    "AWS::ECR::RepositoryCreationTemplate": "38e9548ebe8ec1f5",
+    "AWS::ECS::CapacityProvider": "683155ff5bdccc42",
     "AWS::ECS::Cluster": "3990111074eac8be",
     "AWS::ECS::ClusterCapacityProviderAssociations": "4b512d1fe30ffdd3",
     "AWS::ECS::PrimaryTaskSet": "d8ea9e906cb85b80",
-    "AWS::ECS::Service": "75313434fba04f66",
+    "AWS::ECS::Service": "585001d48158728c",
     "AWS::ECS::TaskDefinition": "ac3c5ff140cb5d7d",
     "AWS::ECS::TaskSet": "93284b06523a426d",
     "AWS::EFS::AccessPoint": "2f62161de474e688",
@@ -312,7 +312,7 @@ types: dict[str, str] = {
     "AWS::EMR::InstanceFleetConfig": "7c6308bb9ea61ce8",
     "AWS::EMR::InstanceGroupConfig": "57ea4fa9b7b6f658",
     "AWS::EMR::SecurityConfiguration": "59f2b8145f1762e6",
-    "AWS::EMR::Step": "816de91a3e21c0a7",
+    "AWS::EMR::Step": "87ecffcedd5d780a",
     "AWS::EMR::Studio": "5562dc4dee066fd3",
     "AWS::EMR::StudioSessionMapping": "68073ac17f83b5d4",
     "AWS::EMRContainers::VirtualCluster": "d56c1799bc259539",
@@ -447,7 +447,7 @@ types: dict[str, str] = {
     "AWS::IoT::ThingGroup": "7fa472878da23f08",
     "AWS::IoT::ThingPrincipalAttachment": "cb2db377e7001773",
     "AWS::IoT::ThingType": "472326c990487efa",
-    "AWS::IoT::TopicRule": "b031e429916b85bb",
+    "AWS::IoT::TopicRule": "4fcf915e11a87a98",
     "AWS::IoT::TopicRuleDestination": "1113af4de44b3cb0",
     "AWS::KMS::Alias": "28f10f922a4d194f",
     "AWS::KMS::Key": "c70e396ee12ddb65",
@@ -576,7 +576,7 @@ types: dict[str, str] = {
     "AWS::Route53::HostedZone": "29b2fce456164442",
     "AWS::Route53::RecordSet": "c01e9eccec2e3b83",
     "AWS::Route53::RecordSetGroup": "8300e7c48d942273",
-    "AWS::Route53Profiles::Profile": "cf36999836466e94",
+    "AWS::Route53Profiles::Profile": "cb0a28f9bebd044e",
     "AWS::Route53Profiles::ProfileAssociation": "fa568e44f7d9e9f2",
     "AWS::Route53Profiles::ProfileResourceAssociation": "73d6b9da50afa75b",
     "AWS::Route53Resolver::FirewallDomainList": "76957613d7f85b1b",
@@ -593,12 +593,17 @@ types: dict[str, str] = {
     "AWS::S3::AccessGrantsInstance": "05d3e874b43bbad8",
     "AWS::S3::AccessGrantsLocation": "3a7be1727f630029",
     "AWS::S3::AccessPoint": "e8b95810dd8d6917",
-    "AWS::S3::Bucket": "1aa877c9b86f9e89",
+    "AWS::S3::Bucket": "bc2a891a463ee5ee",
     "AWS::S3::BucketPolicy": "38ad5b8bd8062535",
     "AWS::S3::StorageLens": "e20ccca5b946adc3",
     "AWS::S3::StorageLensGroup": "a48c03e67d334c14",
     "AWS::S3ObjectLambda::AccessPoint": "2d6b2b82a9508114",
     "AWS::S3ObjectLambda::AccessPointPolicy": "fd6328c6c782223a",
+    "AWS::S3Tables::Namespace": "44b5d6ca79e89650",
+    "AWS::S3Tables::Table": "9fef59bdfa5bd960",
+    "AWS::S3Tables::TableBucket": "f26569515da002c0",
+    "AWS::S3Tables::TableBucketPolicy": "b3ab0f647d7aed60",
+    "AWS::S3Tables::TablePolicy": "0ed301e1967bd6a0",
     "AWS::SDB::Domain": "48c38397df169b43",
     "AWS::SNS::Subscription": "9426c559a25e9da6",
     "AWS::SNS::Topic": "dfcf55503343941a",
@@ -610,8 +615,8 @@ types: dict[str, str] = {
     "AWS::SSM::Association": "ad263c9023f92e0c",
     "AWS::SSM::Document": "8b3a8b629d6edee1",
     "AWS::SSM::MaintenanceWindow": "54b31dcf040d1e3b",
-    "AWS::SSM::MaintenanceWindowTarget": "ab8754ee279cfae2",
-    "AWS::SSM::MaintenanceWindowTask": "4655ff7a49ab0f29",
+    "AWS::SSM::MaintenanceWindowTarget": "16bcb928c1d2233d",
+    "AWS::SSM::MaintenanceWindowTask": "ce68f32e2ef0a575",
     "AWS::SSM::Parameter": "c247b226112c5ae5",
     "AWS::SSM::PatchBaseline": "43cce065b6753223",
     "AWS::SSM::ResourceDataSync": "f92ce1aa6674b7f2",
@@ -645,8 +650,8 @@ types: dict[str, str] = {
     "AWS::Scheduler::Schedule": "e8b60514af25a837",
     "AWS::Scheduler::ScheduleGroup": "ef710d09dbb243bf",
     "AWS::SecretsManager::ResourcePolicy": "cb5d330bf15d9d5a",
-    "AWS::SecretsManager::RotationSchedule": "1f88d2e8812cdf5d",
-    "AWS::SecretsManager::Secret": "4817d08ab5bef439",
+    "AWS::SecretsManager::RotationSchedule": "e02692fb717f1c08",
+    "AWS::SecretsManager::Secret": "9ee06ee7d6dbf7cf",
     "AWS::SecretsManager::SecretTargetAttachment": "3bf4404734c82308",
     "AWS::SecurityHub::AutomationRule": "f6c9ad12353e867b",
     "AWS::SecurityHub::ConfigurationPolicy": "acb80ff79b887cb5",
